<?php

// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) exit;

/**
 * Adyen Notifications Class
 *
 * @since 0.4
 */
class WC_Gateway_Adyen_Notifications {
    
    /**
     * Class Constructor
     */
    function __construct() {
        add_action( 'woocommerce_api_wc_gateway_adyen', array( $this, 'check_response' ) );
        add_action( 'valid-adyen-http-post-notification', array( $this, 'valid_response' ) );
    }
    
    /**
     * Check Response from Adyen
     *
     * @since 0.4
     */
    public function check_response() {
        if( ! empty( $_POST ) && $this->validate_ipn( $_POST ) ) {
            $posted = wp_unslash( $_POST );
            
            do_action( 'valid-adyen-http-post-notification', $posted );
            exit();
        }
        exit("[accepted]");
    }
    
    /**
     * Check Adyen IPN validity.
     *
     * @since 0.4
     */
    public function validate_ipn( $posted ) {
        if( $posted['success'] !== 'true' ) {
            return false;
        }
        
        return true;
    }
    
    /**
     * Valid Response from Adyen
     *
     * @since 0.4
     */
    public function valid_response( $posted ) {
        $order_id = WC_Gateway_Adyen_Helper::extract_order_id( $posted );
        switch( $posted['eventCode'] ) {
            case 'AUTHORISATION':
                // Order completed.
                self::update_order_status( $order_id, 'completed', __( 'Payment completed via Adyen.', 'adyen' ) );
            break;
            case 'CANCELLATION':
                // Order cancelled.
                self::update_order_status( $order_id, 'cancelled', __( 'Payment cancelled via Adyen.', 'adyen' ) );
            break;
            case 'REFUND':
                // Order refunded.
                self::update_order_status( $order_id, 'refunded', __( 'Payment refunded via Adyen.', 'adyen' ) );
            break;
            case 'CANCEL_OR_REFUND':
                // Do something.
            break;
            case 'CAPTURE':
                // Order completed.
                self::update_order_status( $order_id, 'completed', __( 'Payment completed via Adyen.', 'adyen' ) );
            break;
            case 'REFUNDED_REVERSED':
                // Order refund reversed.
                self::update_order_status( $order_id, 'completed', 'reversed', __( 'Payment reversed via Adyen.', 'adyen' ) );
            break;
            case 'CAPTURE_FAILED':
                // Order failed.
                self::update_order_status( $order_id, 'failed', __( 'Payment failed via Adyen.', 'adyen' ) );
            break;
            case 'REQUEST_FOR_INFORMATION':
                // Do something.
            break;
            case 'NOTIFICATION_OF_CHARGEBACK':
                // Order on-hold. (dispute opened)
                self::update_order_status( $order_id, 'on-hold', __( 'Payment on-hold via Adyen.', 'adyen' ) );
            break;
            case 'CHARGEBACK':
                // Order refunded.
                self::update_order_status( $order_id, 'refunded', __( 'Payment refunded via Adyen.', 'adyen' ) );
            break;
            case 'CHARGEBACK_REVERSED':
                // Money reversed, update order to completed.
                self::update_order_status( $order_id, 'completed', __( 'Chargeback reversed via Adyen.', 'adyen' ) );
            break;
            case 'REPORT_AVAILABLE':
                // Do something.
            break;
        }
        echo "[accepted]";
    }
    
    /**
     * Adyen Update Order Status
     *
     * @since 0.4
     */
    public static function update_order_status( $order_id, $status = 'failed', $note = '' ) {
        $order = new WC_Order( $order_id );
        
        // Update order.
        $order->update_status( $status, $note );
        
        if( WC_Gateway_Adyen::$sandbox == 'yes' ) {
            $info = __( 'TEST MODE', 'adyen' ) . ' #' . $order_id . ': ' . $note; 
        } else {
            $info = '#' . $order_id . ': ' . $note;
        }
        
        // Write order status in log file.
        if( WC_Gateway_Adyen::$log_enabled == 'yes' ) {
            WC_Gateway_Adyen::log( $info );
        }
    }
}
